# SpaceRocks

SpaceRocks is an open-source software written in Python. It is a suite of tools needed to perform a number of tasks relevant to Solar System dynamics, both observational and theoretical.

`pip install spacerocks`
